#
# spec file for package mfgtools
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mfgtools
Version:        1.5.191.0
Release:        1.3
Summary:        Freescale/NXP I.MX Chip image deploy tools
License:        BSD-3-Clause
Group:          System/Management
URL:            https://github.com/NXPmicro/mfgtools.git
Source0:        %{name}-%{version}.tar
Patch0:         mfgtools-gcc13.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libbz2-devel
BuildRequires:  libopenssl-devel
BuildRequires:  libusb-1_0-devel
BuildRequires:  libzip-devel
BuildRequires:  libzstd-devel
BuildRequires:  pkg-config
BuildRequires:  tinyxml2-devel
BuildRequires:  zlib-devel

%description
Freescale/NXP I.MX Chip image deploy tools. This package holds the evolution of MFGTools (aka MFGTools v3), which is called the UUU (Universal Update Utility).

%prep
%autosetup -p1

%build
echo uuu_%{version} > .tarball-version
cmake .
make

%install
mkdir -p %{buildroot}%{_bindir}
install uuu/uuu %{buildroot}%{_bindir}

%files
%license LICENSE
%doc README.md
%{_bindir}/uuu

%changelog
* Thu Oct 31 2024 Matthias Brugger <mbrugger@suse.com>
- Add tinyxml2-devel to BuildRequiers
- Update to version 1.5.191.0
  - Reduce memory usage when burn single board with compressed Image.
  - Http(s) prompt request username and passwords when require autherization.
  - fix memory leak cause by getaddrinfo.
  - fix crash when environment variable is last word in script
  - Expand upload command, like uploading the value of a specific variable
  - Fix segfault when boot data is zero in SDP.
  - Fix issues when m_skip is not zero in fastboot.
  - Fix issues when file size isn't divisible by block size in fastboot.
  - Fix read uploaded data for FB.
  - static link c++ library in prebuild linux image
  - provide armlinux version image
  - Add built spinand command support
  - parser [-t timeout] for all protocol
  - force use old libusb to run at ubuntu 18.04
  - Increase default timeout to 10s
  - Hot Fixed for SPDS crash for some images
  - Support i.MX95
  - Fixed usb pipe error when download image with FCB
  - Support i.MX91
  - Fixed a crash with -d option when change back file.
  - Fix crash when get serial number at SPL/uboot if no serial_no exist at device descriptor
  - Fix "imx91" device name as "imx93" when -lsusb
  - Add dynamic `g_max_process_width` global variable to handle long lines
* Fri Oct 25 2024 Matthias Brugger <mbrugger@suse.com>
- Update to version 1.5.182.9
  - Reduce memory usage when burn single board with compressed Image.
  - Http(s) prompt request username and passwords when require autherization.
  - fix memory leak cause by getaddrinfo.
  - fix crash when environment variable is last word in script
  - Expand upload command, like uploading the value of a specific variable
  - Fix segfault when boot data is zero in SDP.
  - Fix issues when m_skip is not zero in fastboot.
  - Fix issues when file size isn't divisible by block size in fastboot.
  - Fix read uploaded data for FB.
  - static link c++ library in prebuild linux image
  - provide armlinux version image
  - Add built spinand command support
  - parser [-t timeout] for all protocol
  - force use old libusb to run at ubuntu 18.04
  - Increase default timeout to 10s
  - Hot Fixed for SPDS crash for some images
  - Support i.MX95
  - Fixed usb pipe error when download image with FCB
  - Support i.MX91
  - Fixed a crash with -d option when change back file.
  - Fix crash when get serial number at SPL/uboot if no serial_no exist at device descriptor
  - Fix "imx91" device name as "imx93" when -lsusb
  - Add dynamic `g_max_process_width` global variable to handle long lines
* Mon Apr 17 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add mfgtools-gcc13.patch: Fix build using GCC 13.
* Mon Sep  5 2022 Matthias Brugger <mbrugger@suse.com>
- Update to version 1.4.243.7
- Sort BuildRequiers alphabetically
- Add libzstd-devel to BuildRequiers
* Thu Jul 14 2022 Matthias Brugger <mbrugger@suse.com>
- Update to version 1.4.224.8
* Thu Apr 29 2021 Matthias Brugger <mbrugger@suse.com>
- Add first version
